%\BeginDoc
%
%\Name: linear_combos 
%
%\Description: 
%   This code make a linear combination of two vectors and the resulted 
%   vectors are tested for minimality. 
%
%\Arguments
%   v1,v2      Vectors with dimention n. 
%
%\Program outputs:
%   Nnew       Contains linear combinations of v1 and v2.  
%              
%\EndDoc
%
%-------------------------------------------------------------------------    
%          
%        
    function [Nnew] = linear_combos(N,v1,v2);  
%    
%   %----------------%
%   | Initialization |
%   %----------------%
%      
    Nnew = [];  
    Nnew = [Nnew (v1+v2) (v1-v2)]; 
%    
%   %---------------------------------------------------------------------%
%   | Construct new linear combination so that its i-th entry be zero.    |
%   %---------------------------------------------------------------------%
%     
    n = length(v1);
    for i = 1:n
      v1i = v1(i);
      v2i = v2(i);
      if (v1i ~= 0) & (v2i ~= 0) & ( (abs(v1i)~=1)|(abs(v2i)~=1) )   
        Nnew = [Nnew (v2i.*v1 - v1i.*v2)];
      end            
    end
%    
%   %----------------------------------%
%   | Safeguard wrt numerical error.   | 
%   %----------------------------------%
%
    epsilon = 1e-10;
    Nnew = Nnew.*( abs(Nnew) > epsilon );
%   
%   %----------------------------%    
%   | Guarantee Nnew are minimal |    
%   %----------------------------%
%
    Nnew = test_new_vectors(N,Nnew,2);  
    Nnew = test_new_vectors(N,Nnew,1);
%    
%  %------------------------------------%
%  | End of linear_combos function      |
%  %------------------------------------%
